### Getting Started

PDFMathTranslate is a powerful PDF translation tool. You can install and start using this tool in various ways.

---

### Installation

1. [**Windows EXE**](./INSTALLATION_winexe.md) <small>Recommand for Windows</small>
2. [**Docker**](./INSTALLATION_docker.md) <small>Recommand for Linux</small>
3. [**uv** (a Python package manager)](./INSTALLATION_uv.md) <small>Recommand for macOS</small>

---

### Usage

1. [Using **WebUI**](./USAGE_webui.md)
2. [Using **Zotero Plugin**](https://github.com/guaguastandup/zotero-pdf2zh) (Third party programm)
3. [Using **Commandline**](./USAGE_commandline.md)